@@ -140,11 +140,11 @@ sub mv {
     my ($self, $from, $to, $limit) = @_;
     my @from = $self->newpath($from);
     my @to   = $self->newpath($to);
-    die "$from[1]? expected main|busy|time|failed" if !exists $type{$from[1]};
-    die "$to[1]? expected main|busy|time|failed" if !exists $type{$to[1]};
-    die "Path length should be 2: " . join('/',@from) if @from != 2;
-    die "Path length should be 2: " . join('/',@to) if @to != 2;
-    die "from and to are same" if join('',@from) eq join('',@to);
+    die "$from[1]? expected main|busy|time|failed\n" if !exists $type{$from[1]};
+    die "$to[1]? expected main|busy|time|failed\n" if !exists $type{$to[1]};
+    die "Path length should be 2: " . join('/',@from) . "\n" if @from != 2;
+    die "Path length should be 2: " . join('/',@to) . "\n" if @to != 2;
+    die "from and to are the same\n" if join('',@from) eq join('',@to);
 
     my $conn = $self->conn;
     my $count = 0;
@@ -156,10 +156,28 @@ sub mv {
     }
     return $count;
 }
+sub cp {
+   my ($self, $from, $to, $limit) = @_;
+    my @from = $self->newpath($from);
+    my @to   = $self->newpath($to);
+    die "$from[1]? expected main|busy|time|failed\n" if !exists $type{$from[1]};
+    die "$to[1]? expected main|busy|time|failed\n" if !exists $type{$to[1]};
+    die "Path length should be 2: " . join('/',@from) . "\n" if @from != 2;
+    die "Path length should be 2: " . join('/',@to) . "\n" if @to != 2;
+    my $conn = $self->conn;
+    my $redis_from = join('_', @from);
+    my $redis_to = join('_', @to);
+
+    my $length= $conn->llen($redis_from);
+    my @elements = $conn->lrange($redis_from, 0, ($limit || $length ) - 1 );
+    $conn->rpush($redis_to, @elements) if @elements;
+    return scalar @elements;
+}
+
 sub rm {
     my ($self, $dir, $limit) = @_;
     my @dir = $self->newpath($dir);
-    die "not a complete path" if (@dir != 2);
+    die "not a complete path\n" if (@dir != 2);
     my $redisname = join '_', @dir;
     my $conn = $self->conn;
     my $count = 0;
@@ -183,8 +201,8 @@ sub who {
 }
 sub cleanup {
     my ($self, $timeout, $action) = @_;
-    die "not connected" if !defined $self->path;
-    die "command not available here" if @{$self->path} < 1;
+    die "not connected\n" if !defined $self->path;
+    die "command not available here\n" if @{$self->path} < 1;
     my @items = $self->{redis}->handle_expired_items($timeout, $action);
     return scalar @items;
 }
@@ -203,7 +221,7 @@ sub show_prompt {
 }
 
 sub run {
-    my $self = shift;
+    my ($self, %params) = @_;
     $| = 1;
 
     my @history;
@@ -211,8 +229,8 @@ sub run {
 
     # take settings from previous session
     my $conf_file = "$ENV{HOME}/.reliablefifo";
-    my %conf = ();
-    if (-f $conf_file) {
+    my %conf;
+    if (!$params{ignore_config_file} and -f $conf_file) {
         %conf = %{decode_json(read_file($conf_file))};
         $self->open(server => $conf{server},  port => $conf{port})
             if exists $conf{server} && exists $conf{port};
@@ -247,6 +265,7 @@ sub run {
         close
         db
         mv
+        cp
         rm
         who
         quit
@@ -261,6 +280,7 @@ sub run {
                 "ls [<path>]",
                 "cd <path>",
                 "mv <path-from> <path-to> [<limit>]",
+                "cp <path-from> <path-to> [<limit>]",
                 "cleanup <timeout> <(requeue|fail|drop)>", 
                 'rm <path> [<limit>]',
                 'db <db>',
@@ -346,6 +366,9 @@ sub run {
                     elsif ($cmd eq "mv") {
                         printf "%d items moved\n", $self->mv(@args);
                     }
+                    elsif ($cmd eq "cp") {
+                        printf "%d items copied\n", $self->cp(@args);
+                    }
                     elsif ($cmd eq 'ls') {
                         print join("\n", $self->ls(@args)), "\n";
                     }
@@ -374,7 +397,7 @@ sub run {
                     1;
                 }
                 or do {
-                    print "$@\n";
+                    print $@;
                 }
             }
             else {
@@ -406,7 +429,8 @@ in your PATH.
 
 The last state of the cli session is saved in $ENV{HOME}/.reliablefifo
 (as JSON). When restarting the cli, the previous context will be
-reloaded, i.e. connection, directory and history
+reloaded, i.e. connection, directory and history (unless the
+parameter C<ignore_config_file> is passed to run()).
 
 The command a in unix style, like "ls", "cd", "rm" and "mv". Press "?"
 to get a list of available commands. A directory structure is emulated
