@@ -11,7 +11,6 @@ use strict;
 
 use Redis;
 use Getopt::Std;
-use Data::Dumper;
 
 use constant {
     OK       => 0,
@@ -23,7 +22,6 @@ use constant {
 my %opts;
 getopts('H:p:q:w:c:?hv', \%opts);
 
-#print Dumper(\%opts);
 usage() if ( exists $opts{h} || exists $opts{'?'}
     || !exists $opts{H}) || !exists $opts{q};
 
